@@ -81,8 +81,6 @@ def preprocessing_training_common(df, config, industry_dictionary, state_diction
     # Create Company years column
     df = devutils.create_company_years_column( df=df )
 
-    # Extract relevant status from bulkstatus
-    df = devutils.process_bulkstatus(df)
 
     # Create new seniorities and the rest go to "other"
     df = devutils.fill_seniority_column( df=df )
