@@ -38,9 +38,9 @@ def set_dataframe_columntypes(df):
     if 'idCampaign' in df:
         df['idCampaign'] = df['idCampaign'].astype('Int64')
         df['idCampaign'] = df['idCampaign'].apply(str)
-    # if 'BulkStatus' in df:
-    #     df['BulkStatus']=df['BulkStatus'].astype('str')
-    #     df['BulkStatus'] = df['BulkStatus'].astype('object')
+    if 'BulkStatus' in df:
+        df['BulkStatus']=df['BulkStatus'].astype('Int64')
+        df['BulkStatus'] = df['BulkStatus'].apply(str)
     if 'campaign_bulk_date' in df:
         df['campaign_bulk_date'] = df['campaign_bulk_date'].astype('object')
         df['campaign_bulk_date'] = pd.to_datetime(df['campaign_bulk_date'])
